@@ -20,7 +20,12 @@ from .const import (
 
 from .model import Py2NConnectionData
 
-from .exceptions import DeviceConnectionError, DeviceUnspportedError, ApiError, DeviceApiError
+from .exceptions import (
+    DeviceConnectionError,
+    DeviceUnspportedError,
+    ApiError,
+    DeviceApiError,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -30,24 +35,28 @@ async def get_info(
 ) -> dict[str, Any]:
     """Get info from device through REST call."""
     try:
-        await api_request(
+        result = await api_request(
             aiohttp_session, options, f"http://{options.host}{API_SYSTEM_INFO}"
         )
     except DeviceApiError as err:
         raise
 
+    return result
+
 
 async def get_status(
     aiohttp_session: aiohttp.ClientSession, options: Py2NConnectionData
 ) -> dict[str, Any]:
     """Get status from device through REST call."""
     try:
-        await api_request(
+        result = await api_request(
             aiohttp_session, options, f"http://{options.host}{API_SYSTEM_STATUS}"
         )
     except DeviceApiError as err:
         raise
 
+    return result
+
 
 async def restart(
     aiohttp_session: aiohttp.ClientSession, options: Py2NConnectionData
@@ -78,7 +87,7 @@ async def get_switches(
 ) -> List[Any]:
     """Get switches from device through REST call."""
     try:
-        await api_request(
+        result = await api_request(
             aiohttp_session, options, f"http://{options.host}{API_SWITCH_STATUS}"
         )
     except DeviceApiError as err:
@@ -87,13 +96,15 @@ async def get_switches(
             return []
         raise
 
+    return result["switches"]
+
 
 async def set_switch(
     aiohttp_session: aiohttp.ClientSession,
     options: Py2NConnectionData,
     switch_id: int,
     on: bool,
-) -> List[Any]:
+) -> None:
     """Set switch value of device via REST call."""
     try:
         await api_request(
@@ -115,7 +126,7 @@ async def api_request(
         ) as response:
             if response.content_type != CONTENT_TYPE:
                 raise DeviceUnspportedError("invalid content type")
-                
+
             result: dict[str, Any] = await response.json()
     except CONNECT_ERRORS as err:
         error = DeviceConnectionError(err)
@@ -134,4 +145,4 @@ async def api_request(
         _LOGGER.debug("host %s: api error: %r", options.host, err)
         raise err
 
-    return result
+    return result["result"]
